reuse-download - reuse 6.1.2 documentation

Skip to content
Back to top
View this page

# reuse-download

## Synopsis

reuse download [options] [license …]

## Description

reuse-download downloads licenses into your `LICENSES/` directory.

The license arguments must be SPDX License Identifiers.

The `LICENSES/` directory will be found in the root of your project. If you are already in a directory named `LICENSES` and you are not in a VCS repository, that directory will be used.

If no `LICENSES/` directory exists, one will be created.

## Options

--all

  Download all licenses detected missing in the project.

-o, --output FILE

  If downloading a single file, output it to a specific file instead of putting it in a detected `LICENSES/` directory.

--source PATH

  Specify a source from which to copy custom `LicenseRef-` files. This can be a directory containing such file, or a path to the file itself.

--help

  Display help and exit.